@@ -54,6 +54,12 @@ class JobTemplate(HasCopy, HasCreate, HasInstanceGroups, HasNotifications, HasSu
             'ask_tags_on_launch',
             'ask_variables_on_launch',
             'ask_verbosity_on_launch',
+            'ask_execution_environment_on_launch',
+            'ask_labels_on_launch',
+            'ask_forks_on_launch',
+            'ask_job_slice_count_on_launch',
+            'ask_timeout_on_launch',
+            'ask_instance_groups_on_launch',
             'allow_simultaneous',
             'become_enabled',
             'diff_mode',
@@ -73,6 +79,7 @@ class JobTemplate(HasCopy, HasCreate, HasInstanceGroups, HasNotifications, HasSu
             'webhook_service',
             'webhook_credential',
             'scm_branch',
+            'prevent_instance_group_fallback',
         )
 
         update_payload(payload, optional_fields, kwargs)
